@@ -95,7 +95,7 @@ class PostgresTargetConnector(C8Connector):
             ConfigProperty('target_table', 'Target Table', ConfigAttributeType.STRING, True, False,
                            description='Destination table name.',
                            placeholder_value='my_table'),
-            ConfigProperty('hard_delete', 'Hard Delete', ConfigAttributeType.BOOLEAN, True, False,
+            ConfigProperty('hard_delete', 'Hard Delete', ConfigAttributeType.BOOLEAN, False, False,
                            description='When `hard_delete` option is true then DELETE SQL commands will be performed '
                                        'in Postgres to delete rows in tables. It is achieved by continuously checking '
                                        'the `_SDC_DELETED_AT` metadata column sent by the singer tap. Due to deleting '
@@ -230,6 +230,7 @@ def persist_lines(config, lines) -> None:
     """Read singer messages and process them line by line"""
     state = None
     flushed_state = None
+    hard_delete = config.get('hard_delete', False)
     schemas = {}
     key_properties = {}
     validators = {}
@@ -294,7 +295,7 @@ def persist_lines(config, lines) -> None:
                 total_row_count[stream] += 1
 
             # append record
-            if config.get('add_metadata_columns') or config.get('hard_delete'):
+            if config.get('add_metadata_columns') or hard_delete:
                 records_to_load[stream][primary_key_string] = add_metadata_values_to_record(o)
             else:
                 records_to_load[stream][primary_key_string] = o['record']
@@ -361,7 +362,7 @@ def persist_lines(config, lines) -> None:
 
             key_properties[stream] = o['key_properties']
 
-            if config.get('add_metadata_columns') or config.get('hard_delete'):
+            if config.get('add_metadata_columns') or hard_delete:
                 stream_to_sync[stream] = DbSync(config, add_metadata_columns_to_schema(o))
             else:
                 stream_to_sync[stream] = DbSync(config, o)
@@ -442,7 +443,7 @@ def flush_streams(
             records_to_load=streams[stream],
             row_count=row_count,
             db_sync=stream_to_sync[stream],
-            delete_rows=config.get('hard_delete'),
+            delete_rows=config.get('hard_delete', False),
             temp_dir=config.get('temp_dir')
         ) for stream in streams_to_flush)
 
