@@ -226,7 +226,7 @@ class DbSync:
         # Init stream schema
         if stream_schema_message is not None:
             # Define initial list of indices to created
-            self.hard_delete = self.connection_config.get('hard_delete')
+            self.hard_delete = self.connection_config.get('hard_delete', False)
             if self.hard_delete:
                 self.indices = ['_sdc_deleted_at']
             else:
